Attribute VB_Name = "M40xDLL"
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
' LAWSON LABS INC.
' 3217 Phoenixville Pike
' Malvern, PA 19355
' 800-321-5355 or 610 725-8800
' http://www.lawsonlabs.com
' Version: 1.0
' Last Modified: 12/11/2007
'
' DESCRIPTION:
' Has M40x.dll's exported functions, structures and constants declarations
' DON'T MODIFY THIS MODULE.
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''

Option Explicit

Private hLibLL_M40x As Long      'DLL lib point
Private hLibCheck As Long        'library load check
Public M40xDLL_szError As String
Public M40xDLL_szPath As String


'CONSTANTS
Public Const EXTENDED_CAL_SCAN = &HA3
Public Const EXTENDED_SCAN = &HA2
Public Const MAX_DATA_POINTS = 255          'Max. data points for each package
Public Const MAX_SDGROUP = 255              'for standard derviation calculation only
Public Const MAX_CHANNELS = 8               'Max. scan channel number
Public Const SINGLE_CHAN_SCAN = &H87        'Single scan command token
Public Const MULT_CHAN_SCAN = &H88          'Multi channel scan token
Public Const MULT_CHAN_CAL_SCAN = &H89      'Multi channel scan with calibration
Public Const POLLED_MODE = &HA0             'Polled mode command token
Public Const NumOf401s = 8                  'Max demo supports but dll can support upto 64
Public Const MAX_EXTRA_SETTING = 20         'Max number of extra settings that can be stored

'RETURN_CODE ENUM DECLARATION
Public Enum RETURN_CODE     'Error return code from DLL
    COMMAND_SUCCESS = 0
    CALIBRATE_DEV_FAILED
    GET_ECHO_FAILED
    INIT_AD_FAILED
    INVALID_ARGUMENT
    RESET_DEV_FAILED
    DEV_TIME_OUT
    VERIFY_CHKSUM_FAILED
    SET_RATE_FAILED
    DEV_NO_POWER
    DEV_NO_IDLE_MODE
    NO_ECHO_COMMAND
    SOCKET_SEND_ERROR
    PENDING                 '02/21/2003
    OUT_OF_SYNC
    FLUSH_TIME_OUT
    LESS_BYTES_RECVD
    SOCKET_EVENT_FAIL
    INVALID_STATE
    RESERVED1
    RESERVED2
    RESERVED3
    RESERVED4
    NOT_CONNECTED
    INIT_TIMER_FAILED
    I0_ERROR
End Enum


'STRUCTURE DECLARATIONS
Public Type SSCAN_VOLTS_BUFF   ' Create Scan volts buffer type
    fVolts(0 To MAX_DATA_POINTS - 1, 0 To MAX_CHANNELS - 1) As Double 'saved scan data buffer
    fVoltsMax(0 To MAX_CHANNELS - 1) As Double    'max volts for this channel data
    fVoltsMin(0 To MAX_CHANNELS - 1) As Double    'min. volts
    fVoltsAvgTmp(0 To 254, 0 To MAX_CHANNELS - 1) As Double 'average tmp buffer
    fVoltsTotal(0 To MAX_CHANNELS - 1) As Double            'tmp sum variable
    fSD(0 To MAX_SDGROUP - 1, 0 To MAX_CHANNELS - 1) As Double 'tmp sum for stand derivation cal.
    fEffectiveBits(0 To MAX_CHANNELS - 1) As Double        'effective bits
    fstDv(0 To MAX_CHANNELS - 1) As Double                 'stardard derivation
    fSDTotal(0 To MAX_CHANNELS - 1) As Double              'stardard derivation total
    ulSDCount(0 To MAX_CHANNELS - 1) As Long               '4 bytes scan count
End Type

Public Type SSCAN_OBJ               ' Create Scan object type
    ulADCounts(0 To MAX_DATA_POINTS - 1) As Long 'A/D data in counts
    bDigIn(0 To MAX_DATA_POINTS - 1) As Byte    'Digital input in byte
    bScanMode As Byte               'The current scan mode
    bLastScanChan As Byte           '
   'In multichannel scan mode, bLastScanChan is used for screen display
    'housekeeping. Only one channel at a time is monitored for min voltage,
    'max voltage, and effective resolution. If your application uses a separate variable
    'for this purpose, (M40xVB uses bSelChan), you can ignore bLastScanChan.
    'bLastScanChan is same as bSelChanOrNumOfChan in single channel mode
    bSelChanOrNumOfChan As Byte     'Selected chan(Single chan mode) Or Total scan channel(Multi scan mode)
    bChanScanAvg As Byte            'Running average
    bScanDataChkSum As Byte         'Check sum of the scan data
    bChkSumErr As Byte              'Check sum error flag
    bScanBuffOverLapped As Byte     'Scan buffer over lapped flag
    bADChipRegCorrupted As Byte     'A/D Chip registor corrupted flag
    ulScanCounts As Long            'scan counts since scan started
    bSDGroup As Byte                'Standard deviation data counts in a group
    fScanRate As Double             'scan rate in single channel
    fMultiChanScanRate As Double    'scan rate in multi channel
    bScanStopped As Byte            'indicates scan is stoped
    bIsValidData As Byte            'when in single channel scan mode & channel is changed, first 4 conversion are invalid
    bADRange As Byte                'Based on A/D board range, bADRange = 1(-5V to 5V) or 2(-1V to 1V)
    ' Based on A/D board range, bADRange = 1(-5V to 5V) or
    ' 2(-1V to 1V) or 3 (-0.1V to 0.1V) or 4 (-0.2V to 0.2V) or
    ' 5 (-0.045V to 0.045V) or 6 (-7V to 7V)
    bPlaceholder1 As Byte           'place holder
    bPlaceholder2 As Byte           'place holder
    bPlaceholder3 As Byte           'place holder
    bMACAddr(0 To 5) As Byte        '6 bytes MAC address
    RevDataPoints As Long           'how many data points in a block
    ui40xID     As Long             'unique ID, identifying an index
    bDataReady As Byte              ' Ignore, no longer used
End Type




' SYSTEM FUNCTION DECLARATION
Declare Function LoadLibrary Lib "Kernel32" Alias "LoadLibraryA" (ByVal lpLibFileName As String) As Long
Declare Function FreeLibrary Lib "Kernel32" (ByVal hLibModule As Long) As Long
Declare Function GetProcAddress Lib "Kernel32" (ByVal hModule As Long, ByVal lpProcName As String) As Long
Declare Function GetModuleFileName Lib "Kernel32" Alias "GetModuleFileNameA" (ByVal hLibModule As Long, ByVal lpLibFullPath As String, ByVal lStringSize As Long) As Long


'M401 DLL EXPORTED FUNCTION DECLARATION
Declare Function Pub_OpenConnection Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByVal lp_addr As String, ByVal port As Integer) As Byte
Declare Function Pub_SetRate Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByRef fRate As Double) As RETURN_CODE
Declare Function Pub_SetRTC Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ) As RETURN_CODE
Declare Function Pub_SetChan Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByVal bChan As Byte) As RETURN_CODE
Declare Function Pub_SetDigOut Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByVal bDigOutByte As Byte) As RETURN_CODE
Declare Function Pub_EndScan Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ) As RETURN_CODE
Declare Function Pub_StartScan Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByVal bScanMode As Byte, ByVal bChanNum As Byte) As RETURN_CODE
Declare Function Pub_GetPolledConv Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByRef ulConvCnt As Double, ByRef bLastDigIn As Byte) As RETURN_CODE
Declare Function Pub_OfsCal Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByRef ulConvCnt As Double) As RETURN_CODE
Declare Function Pub_FsCal Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByRef ulConvCnt As Double) As RETURN_CODE
Declare Function Pub_GetSelfTestRst Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByRef bRetString As Byte) As RETURN_CODE
Declare Function Pub_SetCallBackFunc Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByVal lpGetBlock As Long) As Byte
Declare Function Pub_ReadScanData Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByRef ulNumPointsToRead As Long) As Boolean
Declare Function Pub_NoCallback Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ) As Byte
Declare Function Pub_SetNewIPAddr Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByVal ulNewIPAddr As Long, ByVal ulNewNetMask As Long, ByVal ulNewGateWay As Long, ByVal bDHCPTmOut As Byte) As RETURN_CODE
Declare Sub Pub_ResetScanDataObj Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByVal bScanMode As Byte, ByVal bSelChan As Byte, ByVal bRunningAvg As Byte, ByVal fScanRate As Double)
Declare Sub Pub_ResetMinMax Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ)
Declare Sub Pub_CloseConnection Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ)
Declare Function Pub_PtrTransfer Lib "M40x.dll" (ByRef pScan_v_buff As SSCAN_VOLTS_BUFF, ByRef pScanObj As SSCAN_OBJ) As Byte
Declare Sub Pub_SetThreadPriority Lib "M40x.dll" (ByVal bWhichThread As Byte, ByVal bPriority As Byte)
Declare Function Pub_NetworkEventThread Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ) As Byte
Declare Function Pub_ExtendedScan Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByVal lAD0_FirstChan As Long, ByVal lAD0_LastChan As Long, ByVal lAD1_FirstChan As Long, ByVal lAD1_LastChan As Long, ByVal flgAD6 As Byte, ByVal flgAD7 As Byte, ByVal flgCalibration As Byte, ByVal flgInvertedMux As Byte) As Byte
Declare Function Pub_ReadExScanDataDbl Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByRef fScanVolts As Double, ByRef bDigInp As Byte, ByVal ulNumScansToReturn As Long, ByRef ulNumScansReturned As Long, ByRef ulNumScansInBuff As Long) As Byte
Declare Function Pub_GetExMinMaxEffBits Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByRef pfMin As Double, ByRef pfMax As Double, ByRef pfEffBits As Double) As Byte
Declare Function Pub_SetMaskedDigOut Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByVal bMask As Byte, ByVal bData As Byte) As RETURN_CODE
Declare Sub Pub_Exit Lib "M40x.dll" ()
Declare Function Pub_GetLastError Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ) As RETURN_CODE
Declare Function Pub_GetScanTime Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByVal szStartTime As String, ByVal szStopTime As String, ByRef dblScanTime As Double) As RETURN_CODE
Declare Function Pub_GetTimeDiff Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByRef lDiff As Long) As RETURN_CODE
Declare Function Pub_IsFirmwareVersionGreaterThanEqualTo Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByVal lMonth As Long, ByVal lDay As Long, ByVal lYear As Long) As Byte
Declare Function Pub_GetErrorLogsStr Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByRef bArray As Byte, ByRef lArrayLen As Long, ByRef bPercMemUsed As Byte) As RETURN_CODE
Declare Function Pub_ResetErrorLogs Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ) As RETURN_CODE
Declare Function Pub_EnableErrorLog Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ) As RETURN_CODE
Declare Function Pub_DisableErrorLog Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ) As RETURN_CODE
Declare Function Pub_GetSelfTestRst2 Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByRef bRetString As Byte) As RETURN_CODE
Declare Function Pub_TestPins Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ) As RETURN_CODE
Declare Function Pub_TrigStartScan Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByVal bScanMode As Byte, ByVal bChanNum As Byte, ByVal bTrigInp As Byte, ByVal bUpEdge As Byte) As RETURN_CODE
Declare Function Pub_TrigExtendedScan Lib "M40x.dll" (ByRef pScanObj As SSCAN_OBJ, ByVal lAD0_FirstChan As Long, ByVal lAD0_LastChan As Long, ByVal lAD1_FirstChan As Long, ByVal lAD1_LastChan As Long, ByVal flgAD6 As Byte, ByVal flgAD7 As Byte, ByVal flgCalibration As Byte, ByVal flgInvertedMux As Byte, ByVal bTrigInp As Byte, ByVal bUpEdge As Byte) As Byte

'LOAD M401 DLL FUNCTIONS

'Must call once before using any exported function
Public Function M40xDLL_Init() As Boolean
Dim PathLen As Long
Dim szPath As String * 1000
hLibLL_M40x = LoadLibrary("M40x.dll")   'load the M40x DLL file
M40xDLL_Init = False 'Assume Failure
If hLibLL_M40x = 0 Then
     M40xDLL_szError = "Unable to load M40x.dll"
End If
'Get M40x.dll path
If hLibLL_M40x <> 0 Then
    PathLen = GetModuleFileName(hLibLL_M40x, szPath, 1000)
    If PathLen <> 0 Then
        M40xDLL_szPath = Left$(szPath, PathLen - 8) ' Strip filename from path
    Else
        M40xDLL_szPath = ""
    End If
End If
M40xDLL_Init = CheckLibFuncs()
End Function

'Call before closing the application
Public Sub M40xDLL_Shutdown()
Call Pub_Exit
Call FreeLibrary(hLibLL_M40x)  'free preloaded library
End Sub

Public Function M40xDLL_Register_Method_1(ByRef ScanObj As SSCAN_OBJ, ByRef ScanVoltsBuff As SSCAN_VOLTS_BUFF, ByVal lpProcAddress As Long) As Boolean
M40xDLL_Register_Method_1 = False
If Pub_PtrTransfer(ScanVoltsBuff, ScanObj) = 0 Then
    'Pub_PtrTransfer failed
    M40xDLL_szError = "Pub_PtrTransfer.....Failed"
    Exit Function
End If
If Pub_SetCallBackFunc(ScanObj, lpProcAddress) = 0 Then
    'Pub_SetCallBackFunc failed
    M40xDLL_szError = "Pub_SetCallBackFunc........Failed"
    Exit Function
End If
M40xDLL_Register_Method_1 = True
End Function

Public Function M40xDLL_Register_Method_2(ByRef ScanObj As SSCAN_OBJ, ByRef ScanVoltsBuff As SSCAN_VOLTS_BUFF, ByVal lpProcAddress As Long) As Boolean
M40xDLL_Register_Method_2 = False
If Pub_PtrTransfer(ScanVoltsBuff, ScanObj) = 0 Then
    'Pub_PtrTransfer failed
    M40xDLL_szError = "Pub_PtrTransfer.....Failed"
    Exit Function
End If
If Pub_NetworkEventThread(ScanObj) = 0 Then
    M40xDLL_szError = "Pub_NetworkEventThread.......Failed"
    Exit Function
End If
If Pub_SetCallBackFunc(ScanObj, lpProcAddress) = 0 Then
    'Pub_SetCallBackFunc failed
    M40xDLL_szError = "Pub_SetCallBackFunc........Failed"
    Exit Function
End If
M40xDLL_Register_Method_2 = True
End Function

Public Function M40xDLL_Register_Method_3(ByRef ScanObj As SSCAN_OBJ, ByRef ScanVoltsBuff As SSCAN_VOLTS_BUFF) As Boolean
M40xDLL_Register_Method_3 = False
If Pub_PtrTransfer(ScanVoltsBuff, ScanObj) = 0 Then
    'Pub_PtrTransfer failed
    M40xDLL_szError = "Pub_PtrTransfer.....Failed"
    Exit Function
End If
If Pub_NetworkEventThread(ScanObj) = 0 Then
    M40xDLL_szError = "Pub_NetworkEventThread.......Failed"
    Exit Function
End If
If Pub_NoCallback(ScanObj) = 0 Then
    M40xDLL_szError = "Pub_NoCallback........Failed"
    Exit Function
End If
M40xDLL_Register_Method_3 = True
End Function


Public Function M40xDLL_Register_Method_4(ByRef ScanObj As SSCAN_OBJ, ByRef ScanVoltsBuff As SSCAN_VOLTS_BUFF) As Boolean
M40xDLL_Register_Method_4 = False
If Pub_PtrTransfer(ScanVoltsBuff, ScanObj) = 0 Then
    'Pub_PtrTransfer failed
    M40xDLL_szError = "Pub_PtrTransfer.....Failed"
    Exit Function
End If
If Pub_NoCallback(ScanObj) = 0 Then
    M40xDLL_szError = "Pub_NoCallback........Failed"
    Exit Function
End If
M40xDLL_Register_Method_4 = True
End Function



' INITIALIZE THE DLL

Function CheckLibFuncs() As Boolean
    'before using DLL functions, check their existance
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_OpenConnection")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_CloseConnection")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_SetRate")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_SetChan")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_SetDigOut")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_EndScan")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_StartScan")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_GetPolledConv")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_OfsCal")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_FsCal")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_GetSelfTestRst")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_ResetScanDataObj")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_ResetMinMax")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_ReadScanData")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_NoCallback")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_PtrTransfer")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_SetRTC")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_SetNewIPAddr")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_Exit")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_SetCallBackFunc")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_SetThreadPriority")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_NetworkEventThread")
    If hLibCheck = 0 Then GoTo ExitCheckLibFunc
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_ExtendedScan")
    If hLibCheck = 0 Then
      M40xDLL_szError = "Use DLL version that supports Pub_ExtendedScan"
      GoTo ExitCheckLibFunc
    End If
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_ReadExScanDataDbl")
    If hLibCheck = 0 Then
      M40xDLL_szError = "Use DLL version that supports Pub_ReadExScanDbl"
      GoTo ExitCheckLibFunc
    End If
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_GetExMinMaxEffBits")
    If hLibCheck = 0 Then
      M40xDLL_szError = "Use DLL version that supports Pub_GetExMinMaxEffBits"
      GoTo ExitCheckLibFunc
    End If
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_SetMaskedDigOut")
    If hLibCheck = 0 Then
      M40xDLL_szError = "Use the DLL version that supports Pub_SetMaskedDigOut"
      GoTo ExitCheckLibFunc
    End If
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_GetLastError")
    If hLibCheck = 0 Then
        M40xDLL_szError = "This version of M401 VB Demo application requires a newer version of M40x.dll that supports Pub_GetLastError. Install the latest version of M40x.dll and try again"
        GoTo ExitCheckLibFunc
    End If
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_GetScanTime")
    If hLibCheck = 0 Then
        M40xDLL_szError = "This version of M401 VB Demo application requires a newer version of M40x.dll, one that supports Pub_GetScanTime. Install the latest version of M40x.dll and try again"
        GoTo ExitCheckLibFunc
    End If
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_GetTimeDiff")
    If hLibCheck = 0 Then
        M40xDLL_szError = "This version of M401 VB Demo application requires a newer version of M40x.dll, one that supports Pub_GetTimeDiff. Install the latest version of M40x.dll and try again"
        GoTo ExitCheckLibFunc
    End If
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_IsFirmwareVersionGreaterThanEqualTo")
    If hLibCheck = 0 Then
        M40xDLL_szError = "This version of M401 VB Demo application requires a newer version of M40x.dll, one that supports Pub_IsFirmwareVersionGreaterThanEqualTo. Install the latest version of M40x.dll and try again"
        GoTo ExitCheckLibFunc
    End If
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_GetErrorLogsStr")
    If hLibCheck = 0 Then
        M40xDLL_szError = "This version of M401 VB Demo application requires a newer version of M40x.dll, one that supports Pub_GetErrorLogsStr. Install the latest version of M40x.dll and try again"
        GoTo ExitCheckLibFunc
    End If
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_ResetErrorLogs")
    If hLibCheck = 0 Then
        M40xDLL_szError = "This version of M401 VB Demo application requires a newer version of M40x.dll, one that supports Pub_ResetErrorLogs. Install the latest version of M40x.dll and try again"
        GoTo ExitCheckLibFunc
    End If
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_EnableErrorLog")
    If hLibCheck = 0 Then
        M40xDLL_szError = "This version of M401 VB Demo application requires a newer version of M40x.dll, one that supports Pub_EnableErrorLog. Install the latest version of M40x.dll and try again"
        GoTo ExitCheckLibFunc
    End If
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_DisableErrorLog")
    If hLibCheck = 0 Then
        M40xDLL_szError = "This version of M401 VB Demo application requires a newer version of M40x.dll, one that supports Pub_DisableErrorLog. Install the latest version of M40x.dll and try again"
        GoTo ExitCheckLibFunc
    End If
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_GetSelfTestRst2")
    If hLibCheck = 0 Then
        M40xDLL_szError = "This version of M401 VB Demo application requires a newer version of M40x.dll, one that supports Pub_GetSelfTestRst2. Install the latest version of M40x.dll and try again"
        GoTo ExitCheckLibFunc
    End If
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_TestPins")
    If hLibCheck = 0 Then
        M40xDLL_szError = "This version of M401 VB Demo application requires a newer version of M40x.dll, one that supports Pub_TestPins. Install the latest version of M40x.dll and try again"
        GoTo ExitCheckLibFunc
    End If
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_TrigStartScan")
    If hLibCheck = 0 Then
        M40xDLL_szError = "This version of M401 VB Demo application requires a newer version of M40x.dll, one that supports Pub_TrigStartScan. Install the latest version of M40x.dll and try again"
        GoTo ExitCheckLibFunc
    End If
    hLibCheck = GetProcAddress(hLibLL_M40x, "Pub_TrigExtendedScan")
    If hLibCheck = 0 Then
        M40xDLL_szError = "This version of M401 VB Demo application requires a newer version of M40x.dll, one that supports Pub_TrigExtendedScan. Install the latest version of M40x.dll and try again"
        GoTo ExitCheckLibFunc
    End If
ExitCheckLibFunc:
    CheckLibFuncs = hLibCheck
End Function


